==> haskell-clientsession-0.9.1.2-109-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.2
id: clientsession-0.9.1.2-Dr29AD5aWklAKLyUL7pJPf
key: clientsession-0.9.1.2-Dr29AD5aWklAKLyUL7pJPf
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
abi: b122f783a59097a53cf3a986733abe51
exposed: True
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
import-dirs: /usr/lib/ghc-8.6.5/site-local/clientsession-0.9.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/clientsession-0.9.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/clientsession-0.9.1.2
hs-libraries: HSclientsession-0.9.1.2-Dr29AD5aWklAKLyUL7pJPf
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-4mGTJNwsUu7LJDOWBfkS70
    bytestring-0.10.8.2 cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    cipher-aes-0.2.11-9AQVkLnXjCkKEt3BMixXJL
    cprng-aes-0.6.1-92ZRei9ZKkaFHyJQCnQDt3
    crypto-api-0.13.3-ALzE3By8BvHGVvnn2irh7V
    crypto-random-0.0.9-E4aYqliD5SsKzXXmOmCF7H directory-1.3.3.0
    entropy-0.4.1.4-23NMAjgKyCo3F1ZCvvDJOh
    setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz
    skein-1.0.9.4-CszzWfh6QCWEKzxEAVSxr8
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clientsession-0.9.1.2-110-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.2
id: clientsession-0.9.1.2-JA2M8Txl5TJByVomVNpxDj
key: clientsession-0.9.1.2-JA2M8Txl5TJByVomVNpxDj
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
abi: d75f22394b36b6f9f7ea23ba8bc600ab
exposed: True
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
import-dirs: /usr/lib/ghc-8.6.5/site-local/clientsession-0.9.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/clientsession-0.9.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/clientsession-0.9.1.2
hs-libraries: HSclientsession-0.9.1.2-JA2M8Txl5TJByVomVNpxDj
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-Isuu0DM5i6LOS2qIIf24
    bytestring-0.10.8.2 cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    cipher-aes-0.2.11-9AQVkLnXjCkKEt3BMixXJL
    cprng-aes-0.6.1-92ZRei9ZKkaFHyJQCnQDt3
    crypto-api-0.13.3-ALzE3By8BvHGVvnn2irh7V
    crypto-random-0.0.9-E4aYqliD5SsKzXXmOmCF7H directory-1.3.3.0
    entropy-0.4.1.4-23NMAjgKyCo3F1ZCvvDJOh
    setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz
    skein-1.0.9.4-CszzWfh6QCWEKzxEAVSxr8
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
